@@ -68,7 +68,7 @@ bcopy (from, to, len)
 #endif
 #endif
 
-char *version_string = "GNU sed version 1.17";
+char *version_string = "GNU sed version 1.18";
 
 /* Struct vector is used to describe a chunk of a compiled sed program.  
  * There is one vector for the main program, and one for each { } pair,
@@ -533,7 +533,8 @@ compile_program (vector, open_line)
      int open_line;
 {
   struct sed_cmd *cur_cmd;
-  int ch, pch;
+  int ch = 0;
+  int pch;
   int slash;
   VOID *b;
   unsigned char *string;
